pub struct Path<'r> { /* private fields */ }Expand description
A single multipath route to a namespace.
Implementations
Sourceimpl<'r> Path<'r>
impl<'r> Path<'r>
Sourcepub fn ana_state(&self) -> Result<&'r str>
pub fn ana_state(&self) -> Result<&'r str>
Asymmetric Namespace Access (ANA) state for this path: optimized,
non-optimized, inaccessible, persistent-loss, or change.
Sourcepub fn numa_nodes(&self) -> Result<&'r str>
pub fn numa_nodes(&self) -> Result<&'r str>
Comma-separated list of NUMA nodes reachable through this path.
Only present when built against a libnvme that exposes
nvme_path_get_numa_nodes (added after libnvme 1.8 / Ubuntu 24.04).
Sourcepub fn queue_depth(&self) -> i32
pub fn queue_depth(&self) -> i32
Current queue depth on this path.
Only present when built against a libnvme that exposes
nvme_path_get_queue_depth (added after libnvme 1.8 / Ubuntu 24.04).